
//wire library for i2c
#include <Wire.h>
//library for the display
#include <Adafruit_SSD1306.h>


//Address was found using the i2c port scanner found in the circuit secrets video Raspberry pi pico, i2c and arduino part 1 
#define SCREEN_ADDRESS 0x3C

//display object takes screen width, screen height, the address of the wire object and the reset pin as arguments.
//the reset pin is set to -1 if it shares the arduino reset pin.
Adafruit_SSD1306 display1(128, 64, &Wire1, -1);

//variable to keep track of what channel we are on
int channel=1;

//the dimensions of the splash screen bmp
#define LOGO_HEIGHT   64
#define LOGO_WIDTH    88



//the splash screen bmp
static const unsigned char PROGMEM logo_bmp[] =
{0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
0x00, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x1f, 0xe0, 0x7f, 0xff, 0xff, 
0xff, 0xff, 0xff, 0xff, 0xff, 0xc3, 0xea, 0xff, 0x0f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
0x1d, 0xac, 0x7f, 0xc3, 0xe1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x79, 0xae, 0x7f, 0xf8, 0xc4, 
0xff, 0xff, 0xff, 0xff, 0xff, 0xf1, 0x88, 0xb7, 0xff, 0xfc, 0x1e, 0xff, 0xff, 0xff, 0xff, 0xff, 
0xe7, 0xae, 0xff, 0xff, 0xfe, 0x3e, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xc8, 0x8f, 0x00, 0x07, 0xf8, 
0xe3, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x38, 0x78, 0x3f, 0x20, 0xf3, 0xed, 0xbf, 0xff, 0xff, 0xff, 
0xfe, 0x6c, 0x63, 0xfe, 0xfc, 0x07, 0x07, 0x9f, 0xff, 0xff, 0xff, 0xfc, 0xc4, 0x8f, 0xfb, 0xff, 
0x1c, 0x01, 0xcf, 0xff, 0xff, 0xff, 0xf9, 0x37, 0x3f, 0xf7, 0xfe, 0x38, 0x30, 0x6f, 0xff, 0xff, 
0xff, 0xfb, 0xf4, 0x7f, 0xdf, 0xfc, 0xe0, 0x18, 0x27, 0xff, 0xff, 0xff, 0xf3, 0x79, 0xff, 0xbf, 
0xf1, 0xc4, 0x9e, 0x33, 0xff, 0xff, 0xff, 0xe5, 0x13, 0xd6, 0xff, 0xe7, 0xe7, 0xcf, 0x9b, 0xff, 
0xff, 0xff, 0xc8, 0xe7, 0xfd, 0xff, 0x8e, 0x32, 0xc6, 0xd9, 0xff, 0xff, 0xff, 0xdc, 0x4f, 0xbf, 
0xfe, 0x38, 0x10, 0xe6, 0x19, 0xff, 0xff, 0xff, 0x9e, 0x9f, 0xfd, 0xfc, 0x74, 0x18, 0x73, 0x71, 
0xff, 0xff, 0xff, 0xa7, 0xbf, 0xbf, 0xf1, 0xe2, 0x4c, 0xf1, 0xc7, 0xff, 0xff, 0xff, 0x31, 0x3f, 
0x6b, 0xe7, 0xcd, 0x0c, 0x5b, 0x8f, 0xff, 0xff, 0xff, 0x5e, 0x7d, 0xff, 0x8e, 0x2f, 0x06, 0x0e, 
0x1f, 0xff, 0xff, 0xfe, 0x4a, 0x7b, 0xfe, 0x3c, 0xa7, 0x93, 0x1c, 0xdf, 0xff, 0xff, 0xfe, 0x44, 
0xef, 0xfc, 0x74, 0x63, 0xc8, 0x31, 0xcf, 0xff, 0xff, 0xfe, 0xf4, 0xdf, 0xf9, 0xe2, 0x73, 0xc1, 
0xe7, 0xcf, 0xff, 0xff, 0xfe, 0xfc, 0x7f, 0xe3, 0xcb, 0x19, 0xe3, 0x87, 0xcf, 0xff, 0xff, 0xfc, 
0xf8, 0xff, 0xcf, 0xef, 0x08, 0xa7, 0x27, 0xcf, 0xff, 0xff, 0xfc, 0xf9, 0xff, 0x1c, 0xe1, 0x9c, 
0x3c, 0x67, 0xef, 0xff, 0xff, 0xfd, 0xfb, 0xfc, 0x70, 0x70, 0xcb, 0x39, 0xe7, 0xef, 0xff, 0xff, 
0xfd, 0xfb, 0xf9, 0xe0, 0xf8, 0x49, 0xe3, 0xf7, 0xef, 0xff, 0xff, 0xfd, 0xfb, 0xe3, 0xc8, 0x7c, 
0x21, 0xcf, 0xe7, 0xef, 0xff, 0xff, 0xfd, 0xfb, 0xc7, 0x4a, 0x7f, 0xa7, 0x1f, 0xe7, 0xcf, 0xff, 
0xff, 0xf9, 0xfb, 0x1f, 0x67, 0x3d, 0xbc, 0x7f, 0xe7, 0xcf, 0xff, 0xff, 0xf9, 0xfa, 0x39, 0xa3, 
0x3e, 0x38, 0xff, 0xe7, 0xcf, 0xff, 0xff, 0xfd, 0xf8, 0xe0, 0xf3, 0x9f, 0xe3, 0xff, 0xef, 0xcf, 
0xff, 0xff, 0xfd, 0xf3, 0xc4, 0xf9, 0xcf, 0xcf, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xfd, 0xc7, 0xda, 
0x68, 0xc7, 0x1f, 0xff, 0xcf, 0xdf, 0xff, 0xff, 0xfd, 0x1c, 0xce, 0x3c, 0xce, 0x7f, 0xff, 0xcf, 
0x9f, 0xff, 0xff, 0xfc, 0x38, 0x4f, 0x36, 0x78, 0xff, 0x9f, 0x97, 0x9f, 0xff, 0xff, 0xfc, 0xf0, 
0x27, 0x9e, 0x73, 0xff, 0xbf, 0x9d, 0xbf, 0xff, 0xff, 0xf1, 0xc9, 0x23, 0x8b, 0xc7, 0xfc, 0xff, 
0x31, 0x3f, 0xff, 0xff, 0xe7, 0x8c, 0x33, 0xc3, 0x9f, 0xdd, 0xff, 0x3b, 0x7f, 0xff, 0xff, 0x8e, 
0x24, 0x19, 0xfe, 0x3f, 0xcf, 0xfe, 0x46, 0x7f, 0xff, 0xff, 0xdc, 0xa6, 0x09, 0xbc, 0xfe, 0x8b, 
0xfe, 0xc2, 0xff, 0xff, 0xff, 0xcc, 0xd3, 0x26, 0x71, 0xfd, 0xbf, 0xfc, 0xbc, 0xff, 0xff, 0xff, 
0xe6, 0x79, 0x03, 0xc7, 0xfd, 0x9f, 0xf9, 0x99, 0xff, 0xff, 0xff, 0xf6, 0x79, 0x83, 0x9f, 0xfc, 
0xbf, 0xf2, 0x49, 0xff, 0xff, 0xff, 0xf3, 0x3c, 0xce, 0x3f, 0xfe, 0xff, 0xe6, 0x73, 0xff, 0xff, 
0xff, 0xf9, 0x1c, 0x5c, 0xff, 0xff, 0xff, 0x8c, 0x27, 0xff, 0xff, 0xff, 0xf9, 0x9a, 0x71, 0xff, 
0xff, 0xff, 0x3e, 0x4f, 0xff, 0xff, 0xff, 0xfc, 0xcb, 0xe0, 0x7d, 0xf7, 0xfc, 0x73, 0x9f, 0xff, 
0xff, 0xff, 0xfe, 0xe3, 0x8e, 0x1f, 0xff, 0xf1, 0xb1, 0x3f, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0x3f, 
0x83, 0xff, 0x86, 0x16, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x3c, 0x7f, 0xf0, 0x00, 0x3f, 0x0c, 0xff, 
0xff, 0xff, 0xff, 0xff, 0x90, 0x3f, 0xff, 0xc7, 0xd3, 0x81, 0xff, 0xff, 0xff, 0xff, 0xff, 0x83, 
0x1f, 0xff, 0xd8, 0x80, 0xa3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcf, 0xc7, 0xff, 0xc0, 0xa0, 0x8f, 
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe1, 0xff, 0xc8, 0x0e, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 
0xff, 0xf8, 0x7f, 0x98, 0x70, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0x03, 
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff};

void setup() {
  //set the pins for wire 1
  Wire1.setSDA(2);
  Wire1.setSCL(3);
  
  // Turns on the display at given address using internal voltage
  if(!display1.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS)) {
  //if it cannot start stop the program
    for(;;);
  }

  

  //clear the display buffer
  display1.clearDisplay();
  //call the drawlogo function
  drawlogo();
  //delay to show off the logo before starting the main program
  delay(3000);
  //PrintTextToDisplay();
  
}

void loop() {
  //call function to print the vfo information to the screen
    displayChannelAndFrequency(channel);
    //incriment the channel variable
 channel++;
 //if the channel is above 40 return to channel 1
 if(channel>40){
  channel=1;
 }
 //delay so the display can be read
 delay(150);
}

//function to draw the logo to the screen
void drawlogo(void) {
  //clear the display buffer
  display1.clearDisplay();
//drawBitmap method is called with the desired center position of the image
//the name of the image and the image size
//this draws the bitmap to the buffer
  display1.drawBitmap(
    (display1.width()  - LOGO_WIDTH ) / 2,
    (display1.height() - LOGO_HEIGHT) / 2,
    logo_bmp, LOGO_WIDTH, LOGO_HEIGHT, 1);
//the contents of the buffer are displayed.
  display1.display();
}

//function to display the vfo text takes the channel number as an argument
void displayChannelAndFrequency(int i){
  //we create a string and initialize it to the frequency for channel 1
  String frequency="26.965";
  //we create a switch to set the string to the corrosponding frequency of the selected channel
  switch (i){
    case 1: frequency="26.965";
    break;
    case 2: frequency="26.975";
    break;
    case 3: frequency="26.985";
    break;
    case 4: frequency="27.005";
    break;
    case 5: frequency="27.015";
    break;
    case 6: frequency="27.025";
    break;
    case 7: frequency="27.035";
    break;
    case 8: frequency="27.055";
    break;
    case 9: frequency="27.065";
    break;
    case 10: frequency="27.075";
    break;
    case 11: frequency="27.085";
    break;
    case 12: frequency="27.105";
    break;
    case 13: frequency="27.115";
    break;
    case 14: frequency="27.125";
    break;
    case 15: frequency="27.135";
    break;
    case 16: frequency="27.155";
    break;
    case 17: frequency="27.165";
    break;
    case 18: frequency="27.175";
    break;
    case 19: frequency="27.185";
    break;
    case 20: frequency="27.205";
    break;
    case 21: frequency="27.215";
    break;
    case 22: frequency="27.225";
    break;
    case 23: frequency="27.235";
    break;
    case 24: frequency="27.245";
    break;
    case 25: frequency="27.255";
    break;
    case 26: frequency="27.265";
    break;
    case 27: frequency="27.275";
    break;
    case 28: frequency="27.285";
    break;
    case 29: frequency="27.295";
    break;
    case 30: frequency="27.305";
    break;
    case 31: frequency="27.315";
    break;
    case 32: frequency="27.325";
    break;
    case 33: frequency="27.335";
    break;
    case 34: frequency="27.345";
    break;
    case 35: frequency="27.355";
    break;
    case 36: frequency="27.365";
    break;
    case 37: frequency="27.375";
    break;
    case 38: frequency="27.385";
    break;
    case 39: frequency="27.395";
    break;
    case 40: frequency="27.405";
    break;
  }


  //This code does all of the formating of the text
  //clear the buffer
  display1.clearDisplay();
  //set the text size
  display1.setTextSize(3);
  // Set the text color, the 1306 only supports white
  display1.setTextColor(WHITE);        
  // Set the curser at the top left position
  display1.setCursor(0,0);             
  // Print CH to the display
  display1.println("CH");
  //set the cursor next to the CH text at the top
  display1.setCursor(35,0);             
  // print the channel number
  display1.println(i);
  //set the text size for frequency display
  display1.setTextSize(2);             
  // set the text color
  display1.setTextColor(WHITE);
  // Set the cursor to the left under the channel display
  display1.setCursor(0,25);             
  // print the frequency to the display
  display1.println(frequency);
  //set the cursor next to the frequency
  display1.setCursor(75,25);
  //mhz for megaherts
  display1.println("MHZ");
  //display the buffer
  display1.display();
  
}
